/*
 * Copyright (c) 2021 the original author, All Rights Reserved.
 * Created by Deason on 2021-04-28 22:23:25
 */

package cn.com.qmth.framework.config.center.client.core;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.actuate.endpoint.annotation.Endpoint;
import org.springframework.boot.actuate.endpoint.annotation.ReadOperation;
import org.springframework.core.env.ConfigurableEnvironment;

import java.util.Map;

/**
 * @author: Deason
 * @since: 2021/4/21
 */
@Endpoint(id = "config-refresh")
public class ConfigRefreshEndPoint {

    private static final Logger log = LoggerFactory.getLogger(ConfigRefreshEndPoint.class);

    @Autowired
    private ConfigurableEnvironment environment;

    @ReadOperation
    public String configRefreshEndPoint() {
        try {
            Map<String, Object> remoteProperties = RemotePropertyLoader.call(
                    environment.getProperty(ConfigConstants.CONFIG_CENTER_ADDRESS),
                    environment.getProperty(ConfigConstants.CONFIG_CENTER_NAMESPACE),
                    environment.getProperty(ConfigConstants.CONFIG_CENTER_APP_CODE),
                    environment.getProperty(ConfigConstants.SPRING_PROFILES_ACTIVE),
                    environment.getProperty(ConfigConstants.CONFIG_CENTER_SECRET_KEY)
            );

            CustomMapPropertySource customMapPropertySource = new CustomMapPropertySource(ConfigConstants.CUSTOM_PROPERTY_SOURCE, remoteProperties);
            environment.getPropertySources().addLast(customMapPropertySource);

            return "finished";
        } catch (Exception e) {
            log.warn(e.getMessage(), e);
            return e.getMessage();
        }
    }

}
