/*
 * Copyright (c) 2021 the original author, All Rights Reserved.
 * Created by Deason on 2021-04-28 22:23:25
 */

package cn.com.qmth.framework.config.center.client.core;

import org.springframework.boot.SpringApplication;
import org.springframework.boot.WebApplicationType;
import org.springframework.boot.env.OriginTrackedMapPropertySource;
import org.springframework.core.env.MutablePropertySources;
import org.springframework.core.env.PropertySource;
import org.springframework.core.env.SimpleCommandLinePropertySource;

public interface CustomConfigProcessor {

    default boolean isWebApplication(SpringApplication application) {
        return WebApplicationType.SERVLET == application.getWebApplicationType();
    }

    default void printPropertySources(MutablePropertySources sources) {
        sources.forEach(e -> {
            if (e instanceof SimpleCommandLinePropertySource) {
                this.printProperties(e, ((SimpleCommandLinePropertySource) e).getPropertyNames());
            } else if (e instanceof OriginTrackedMapPropertySource) {
                this.printProperties(e, ((OriginTrackedMapPropertySource) e).getPropertyNames());
            } else if (e instanceof CustomMapPropertySource) {
                this.printProperties(e, ((CustomMapPropertySource) e).getPropertyNames());
            }
        });
    }

    default void printProperties(PropertySource propertySource, String[] propertyNames) {
        System.out.println("\n****************************** " + propertySource.getName());
        for (String propertyName : propertyNames) {
            System.out.println(propertyName + "=" + propertySource.getProperty(propertyName));
        }
        System.out.println("****************************** \n");
    }

}
