/*
 * Copyright (c) 2021 the original author, All Rights Reserved.
 * Created by Deason on 2021-04-28 22:23:25
 */

package cn.com.qmth.framework.config.center.client.core;

import org.springframework.boot.SpringApplication;
import org.springframework.boot.env.EnvironmentPostProcessor;
import org.springframework.core.Ordered;
import org.springframework.core.env.ConfigurableEnvironment;

import java.util.Map;

/**
 * @author: Deason
 * @since: 2021/4/21
 */
public class CustomEnvironmentPostProcessor implements CustomConfigProcessor, EnvironmentPostProcessor, Ordered {

    @Override
    public void postProcessEnvironment(ConfigurableEnvironment environment, SpringApplication application) {
        if (!this.isWebApplication(application)) {
            return;
        }

        EnvProperty.initEnvironment(environment);

        Boolean configCenterEnabled = environment.getProperty(ConfigConstants.CONFIG_CENTER_ENABLED, Boolean.class, false);
        if (!configCenterEnabled) {
            return;
        }

        // 获取远程配置中心的配置项
        Map<String, Object> remoteProperties = RemotePropertyLoader.call(
                environment.getProperty(ConfigConstants.CONFIG_CENTER_ADDRESS),
                environment.getProperty(ConfigConstants.CONFIG_CENTER_NAMESPACE),
                environment.getProperty(ConfigConstants.CONFIG_CENTER_APP_CODE),
                environment.getProperty(ConfigConstants.SPRING_PROFILES_ACTIVE),
                environment.getProperty(ConfigConstants.CONFIG_CENTER_SECRET_KEY)
        );

        CustomMapPropertySource customMapPropertySource = new CustomMapPropertySource(ConfigConstants.CUSTOM_PROPERTY_SOURCE, remoteProperties);
        environment.getPropertySources().addLast(customMapPropertySource);

        if (environment.getProperty("debug", Boolean.class, false)) {
            this.printPropertySources(environment.getPropertySources());
        }
    }

    @Override
    public int getOrder() {
        return LOWEST_PRECEDENCE;
    }

}
