/*
 * Copyright (c) 2021 the original author, All Rights Reserved.
 * Created by Deason on 2021-04-28 22:23:25
 */

package cn.com.qmth.framework.config.center.client.core;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.SpringApplicationRunListener;
import org.springframework.context.ConfigurableApplicationContext;
import org.springframework.core.Ordered;
import org.springframework.core.env.ConfigurableEnvironment;

/**
 * @author: Deason
 * @since: 2021/4/21
 */
public class CustomSpringApplicationRunListener implements CustomConfigProcessor, SpringApplicationRunListener, Ordered {

    private static final Logger log = LoggerFactory.getLogger(CustomSpringApplicationRunListener.class);

    private final SpringApplication application;

    private final String[] args;

    public CustomSpringApplicationRunListener(SpringApplication application, String[] args) {
        this.application = application;
        this.args = args;
    }

    @Override
    public void started(ConfigurableApplicationContext context) {
        if (!this.isWebApplication(application)) {
            return;
        }

        this.notice(context.getEnvironment(), "started");
    }

    @Override
    public void failed(ConfigurableApplicationContext context, Throwable exception) {
        if (!this.isWebApplication(application)) {
            return;
        }

        this.notice(context.getEnvironment(), "failed");
    }

    private void notice(ConfigurableEnvironment environment, String message) {
        Boolean configCenterEnabled = environment.getProperty(ConfigConstants.CONFIG_CENTER_ENABLED, Boolean.class, false);
        if (!configCenterEnabled) {
            return;
        }

        log.debug("notice {}...", message);

        RemotePropertyLoader.notice(
                environment.getProperty(ConfigConstants.CONFIG_CENTER_ADDRESS),
                environment.getProperty(ConfigConstants.CONFIG_CENTER_NAMESPACE),
                environment.getProperty(ConfigConstants.CONFIG_CENTER_APP_CODE),
                environment.getProperty(ConfigConstants.SPRING_PROFILES_ACTIVE),
                message
        );

    }

    @Override
    public int getOrder() {
        return HIGHEST_PRECEDENCE;
    }

}
