/*
 * Copyright (c) 2021 the original author, All Rights Reserved.
 * Created by Deason on 2021-04-28 22:23:25
 */

package cn.com.qmth.framework.config.center.client.core;

import cn.com.qmth.framework.config.center.client.utils.AESUtils;
import com.fasterxml.jackson.databind.JavaType;
import com.fasterxml.jackson.databind.ObjectMapper;
import okhttp3.*;
import org.apache.commons.lang3.StringUtils;

import java.util.HashMap;
import java.util.Map;

/**
 * @author: Deason
 * @since: 2021/4/21
 */
public class RemotePropertyLoader {

    private static final String CONTENT_TYPE = "application/json; charset=UTF-8";

    public static Map<String, Object> call(String address, String namespace, String appCode, String profile, String secretKey) {
        if (StringUtils.isEmpty(address)) {
            throw new IllegalArgumentException(ConfigConstants.CONFIG_CENTER_ADDRESS + " is not exist");
        }

        if (StringUtils.isEmpty(namespace)) {
            throw new IllegalArgumentException(ConfigConstants.CONFIG_CENTER_NAMESPACE + " is not exist");
        }

        if (StringUtils.isEmpty(appCode)) {
            throw new IllegalArgumentException(ConfigConstants.CONFIG_CENTER_APP_CODE + " is not exist");
        }

        if (StringUtils.isEmpty(profile)) {
            throw new IllegalArgumentException(ConfigConstants.SPRING_PROFILES_ACTIVE + " is not exist");
        }

        final String configCenterUrl = String.format("http://%s/config/center/pull/%s/%s/%s",
                address, namespace, appCode, profile);

        RequestBody formBody = FormBody.create(MediaType.parse(CONTENT_TYPE), "{}");
        Request.Builder request = new Request.Builder().url(configCenterUrl).post(formBody);

        final String resp;
        try (Response response = new OkHttpClient.Builder().build().newCall(request.build()).execute();
             ResponseBody body = response.body();) {
            resp = body.string();

            if (response.isSuccessful()) {
                ObjectMapper jsonMapper = new ObjectMapper();
                JavaType javaType = jsonMapper.getTypeFactory().constructMapType(HashMap.class, String.class, Object.class);
                Map<String, Object> properties = jsonMapper.readValue(resp, javaType);

                return decryptProperties(properties, secretKey);
            }
        } catch (Exception e) {
            throw new RuntimeException(configCenterUrl + " call err! " + e.getMessage(), e);
        }

        throw new RuntimeException(configCenterUrl + " call fail! " + resp);
    }

    public static void notice(String address, String namespace, String appCode, String profile, String msg) {
        final String configCenterUrl = String.format("http://%s/config/center/notice/%s/%s/%s?msg=%s",
                address, namespace, appCode, profile, msg);

        RequestBody formBody = FormBody.create(MediaType.parse(CONTENT_TYPE), "{}");
        Request.Builder request = new Request.Builder().url(configCenterUrl).post(formBody);

        try (Response response = new OkHttpClient.Builder().build().newCall(request.build()).execute();) {
        } catch (Exception e) {
            // ignore
        }
    }

    private static Map<String, Object> decryptProperties(Map<String, Object> properties, String secretKey) {
        Map<String, Object> finalProperties = new HashMap<>();

        for (Map.Entry<String, Object> entry : properties.entrySet()) {
            if (entry.getKey().startsWith(ConfigConstants.SECRET_PROPERTY_PREFIX)) {
                finalProperties.put(
                        entry.getKey().substring(ConfigConstants.SECRET_PROPERTY_PREFIX.length()),
                        AESUtils.decrypt(secretKey, String.valueOf(entry.getValue()))
                );
            } else {
                finalProperties.put(entry.getKey(), entry.getValue());
            }
        }

        return finalProperties;
    }

}
