/*
 * Copyright (c) 2021 the original author, All Rights Reserved.
 * Created by Deason on 2021-04-28 22:23:25
 */

package cn.com.qmth.framework.config.center.client.utils;

import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.HashMap;
import java.util.Map;
import java.util.Properties;

public class PropertyUtils {

    private static final Logger log = LoggerFactory.getLogger(PropertyUtils.class);

    private static final String CHARSET_UTF_8 = "UTF-8";

    /**
     * 获取配置文件内容
     */
    public static Properties loadProperties(String... propertyPaths) {
        if (ArrayUtils.isEmpty(propertyPaths)) {
            throw new IllegalArgumentException("propertyPaths must be not empty.");
        }

        log.info("loadProperties, path --> {}", StringUtils.join(propertyPaths, ","));
        Properties properties = new Properties();

        for (String propertyPath : propertyPaths) {
            InputStream is = PropertyUtils.class.getClassLoader().getResourceAsStream(propertyPath);
            if (is == null) {
                String msg = String.format("%s is not exist!", propertyPath);
                throw new IllegalArgumentException(msg);
            }

            try (InputStreamReader isr = new InputStreamReader(is, CHARSET_UTF_8);
                 BufferedReader br = new BufferedReader(isr);) {

                Properties curProperties = new Properties();
                curProperties.load(br);

                // 合并配置项（后面的配置文件内容优先级高于前面的！！！）
                properties.putAll(curProperties);
            } catch (Exception e) {
                log.error(e.getMessage());
                throw new RuntimeException(e);
            } finally {
                try {
                    is.close();
                } catch (IOException e) {
                    // ignore...
                }
            }
        }

        return properties;
    }

    /**
     * 获取配置文件内容
     */
    public static Map<String, String> loadMapProperties(String... propertyPaths) {
        Properties properties = loadProperties(propertyPaths);
        return toMapProperties(properties);
    }

    public static Map<String, String> toMapProperties(Properties properties) {
        Map<String, String> props = new HashMap<>();

        if (properties != null) {
            for (Map.Entry<Object, Object> entry : properties.entrySet()) {
                props.put(String.valueOf(entry.getKey()), String.valueOf(entry.getValue()));
            }
        }

        return props;
    }

}
