/*
 * Copyright (c) 2021 the original author, All Rights Reserved.
 * Created by Deason on 2021-04-28 22:23:21
 */

package cn.com.qmth.framework.config.center.controller;

import cn.com.qmth.framework.config.center.utils.PropertyUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * @author: Deason
 * @since: 2021/4/21
 */
@RestController
@RequestMapping("/config/center")
public class ConfigCenterController extends BaseController {

    private static final Logger log = LoggerFactory.getLogger(ConfigCenterController.class);

    /**
     * 获取配置文件内容
     *
     * @param namespace 命名空间代码
     * @param appCode   应用代码
     * @param profile   环境（如：dev、test、prod）
     * @return
     */
    @RequestMapping(value = "/pull/{namespace}/{appCode}/{profile}", method = {RequestMethod.GET, RequestMethod.POST})
    public Map<String, String> pull(@PathVariable String namespace,
                                    @PathVariable String appCode,
                                    @PathVariable String profile) {
        log.info("IP = {}  namespace = {}  appCode = {}  profile = {}  load...",
                this.currentIP(currentRequest()), namespace, appCode, profile);

        // 根配置文件路径规则：{namespace}/{profile}/application.properties
        final String rootPropertyPath = String.format("%s/%s/application.properties", namespace, profile);

        // 应用配置文件路径规则：{namespace}/{profile}/application-{appCode}.properties
        final String appPropertyPath = String.format("%s/%s/application-%s.properties", namespace, profile, appCode);

        // 合并配置项（后面的配置文件内容优先级高于前面的！！！）
        return PropertyUtils.loadMapProperties(rootPropertyPath, appPropertyPath);
    }

    @RequestMapping(value = "/notice/{namespace}/{appCode}/{profile}", method = {RequestMethod.GET, RequestMethod.POST})
    public void notice(@PathVariable String namespace,
                       @PathVariable String appCode,
                       @PathVariable String profile,
                       @RequestParam(required = false) String msg) {

        log.info("IP = {}  namespace = {}  appCode = {}  profile = {}  msg = {}",
                this.currentIP(currentRequest()), namespace, appCode, profile, msg);
    }

}
